Crate tetsy_trace_time

Crate tetsy_trace_time 

Performance timer with logging

Macros

tetsy_trace_time

Structs

PerfTimer
Performance timer with logging. Starts measuring time in the constructor, prints elapsed time in the destructor or when stop is called.